@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Hash::Util 'lock_keys';
 use List::Util 'first';
@@ -55,27 +55,41 @@ sub new {
     }
 
     my $os                  = $options->{os} || $^O;
+    my $osvers              = '';
     my $linuxdistro         = '';
     my $linuxdistroversion  = 0;
     my $linuxdistrocodename = '';
     if ($os eq 'linux') {
-	my $linux_info = _detect_linux_distribution();
+	my $linux_info;
+	my $get_linux_info = sub {
+	    return $linux_info if $linux_info;
+	    return $linux_info = _detect_linux_distribution();
+	};
 	if (defined $options->{linuxdistro}) {
 	    $linuxdistro = $options->{linuxdistro};
 	} else {
-	    $linuxdistro = lc $linux_info->{linuxdistro};
+	    $linuxdistro = lc $get_linux_info->()->{linuxdistro};
 	}
 
 	if (defined $options->{linuxdistroversion}) {
 	    $linuxdistroversion = $options->{linuxdistroversion};
 	} else {
-	    $linuxdistroversion = $linux_info->{linuxdistroversion}; # XXX make it a version object? or make sure it's just X.Y?
+	    $linuxdistroversion = $get_linux_info->()->{linuxdistroversion}; # XXX make it a version object? or make sure it's just X.Y?
 	}
 
 	if (defined $options->{linuxdistrocodename}) {
 	    $linuxdistrocodename = $options->{linuxdistrocodename};
 	} else {
-	    $linuxdistrocodename = $linux_info->{linuxdistrocodename};
+	    $linuxdistrocodename = $get_linux_info->()->{linuxdistrocodename};
+	}
+    } elsif ($os eq 'freebsd') {
+	# Note: don't use $Config{osvers}, as this is just the OS
+	# version of the system which built the current perl, not the
+	# actually running OS version.
+	if (defined $options->{osvers}) {
+	    $osvers = $options->{osvers};
+	} else {
+	    chomp($osvers = `/sbin/sysctl -n kern.osrelease`);
 	}
     }
 
@@ -98,7 +112,12 @@ sub new {
     my @mapping;
     for my $mapping (@additional_mappings, 'CPAN::Plugin::Sysdeps::Mapping') {
 	if (-r $mapping) {
-	    push @mapping, require $mapping;
+	    open my $fh, '<', $mapping
+		or die "Can't load $mapping: $!";
+	    local $/;
+	    my $buf = <$fh>;
+	    push @mapping, eval $buf;
+	    die "Error while loading $mapping: $@" if $@;
 	} else {
 	    eval "require $mapping"; die "Can't load $mapping: $@" if $@;
 	    push @mapping, $mapping->mapping;
@@ -112,6 +131,7 @@ sub new {
 	 dryrun              => $dryrun,
 	 debug               => $debug,
 	 os                  => $os,
+	 osvers              => $osvers,
 	 linuxdistro         => $linuxdistro,
 	 linuxdistroversion  => $linuxdistroversion,
 	 linuxdistrocodename => $linuxdistrocodename,
@@ -197,6 +217,7 @@ sub _detect_linux_distribution_fallback {
     } else {
 	warn "WARNING: no /etc/issue available";
     }
+    return {};
 }
 
 sub _is_linux_debian_like {
@@ -268,6 +289,8 @@ sub _map_cpandist {
 		    return 0 if !$found && !$TRAVERSE_ONLY;
 		} elsif ($key eq 'os') {
 		    return 0 if !$smartmatch->($self->{os}, $match) && !$TRAVERSE_ONLY;
+		} elsif ($key eq 'osvers') {
+		    return 0 if !$smartmatch->($self->{osvers}, $match) && !$TRAVERSE_ONLY; # XXX should also be able to do numerical comparisons
 		} elsif ($key eq 'linuxdistro') {
 		    if ($match =~ m{^~(debian|fedora)}) {
 			my $method = "_is_linux_$1_like";
