@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
@@ -43,7 +43,7 @@ sub mapping {
        [package => 'hdf']],
       [like_debian,
        # "yasm/nasm not found or too old. Use --disable-yasm for a crippled build."
-       [package => 'yasm']],
+       [package => ['libhdf4-dev', 'yasm']]],
      ],
 
      [cpanmod => 'Alien::LibUSBx',
@@ -59,6 +59,9 @@ sub mapping {
 
      [cpanmod => 'Alien::libtermkey',
       [os_freebsd,
+       [osvers => qr{^\d\d+\.}, # osvers>=10, proxy check for clang system
+	[package => ['libtool', 'gmake', 'pkgconf', 'libtermkey']], # see also RT #91873
+       ],
        [package => ['libtool', 'gmake', 'pkgconf']]],
       [like_debian,
        [linuxdistrocodename => ['squeeze','wheezy'],
